@@ -1,4 +1,3 @@
-
 test_that("creates a deferred value", {
   do <- function() {
     dx <- async_constant()
@@ -17,14 +16,12 @@ test_that("creates a deferred value", {
 
 test_that("resolves to the specified value", {
   do <- function() {
-    async_constant("foobar")$
-      then(function(x) expect_equal(x, "foobar"))
+    async_constant("foobar")$then(function(x) expect_equal(x, "foobar"))
   }
   synchronise(do())
 
   do <- function() {
-    async_constant()$
-      then(function(x) expect_null(x))
+    async_constant()$then(function(x) expect_null(x))
   }
   synchronise(do())
 })
