@@ -1,5 +1,5 @@
-
 test_that("def__make_parent_*", {
+  testthat::local_edition(3)
   good <- list(
     NULL,
     function(x) x,
@@ -12,7 +12,8 @@ test_that("def__make_parent_*", {
     function(a, b, c) resolve(value)
   )
 
-  eta <- function(value, resolve) { }
+  eta <- function(value, resolve) {
+  }
 
   for (f in good) {
     res <- def__make_parent_resolve(f)
@@ -22,8 +23,8 @@ test_that("def__make_parent_*", {
   }
 
   for (f in bad) {
-    expect_error(def__make_parent_resolve(f))
-    expect_error(def__make_parent_reject(f))
+    expect_snapshot(error = TRUE, def__make_parent_resolve(f))
+    expect_snapshot(error = TRUE, def__make_parent_reject(f))
   }
 })
 
@@ -32,52 +33,71 @@ test_that("def__make_parent_resolve", {
   r1 <- def__make_parent_resolve(NULL)
   res <- NULL
   val <- NULL
-  r1(42, function(x) { res <<- "resolve"; val <<- x })
+  r1(42, function(x) {
+    res <<- "resolve"
+    val <<- x
+  })
   expect_equal(res, "resolve")
   expect_equal(val, 42)
 
   ## function without args
-  r2 <-  def__make_parent_resolve(function() 42 * 42)
+  r2 <- def__make_parent_resolve(function() 42 * 42)
   res <- NULL
   val <- NULL
-  r2(42, function(x) { res <<- "resolve"; val <<- x })
+  r2(42, function(x) {
+    res <<- "resolve"
+    val <<- x
+  })
   expect_equal(res, "resolve")
   expect_equal(val, 42 * 42)
 
   ## function with value arg
-  r2 <-  def__make_parent_resolve(function(val) val)
+  r2 <- def__make_parent_resolve(function(val) val)
   res <- NULL
   val <- NULL
-  r2(42, function(x) { res <<- "resolve"; val <<- x })
+  r2(42, function(x) {
+    res <<- "resolve"
+    val <<- x
+  })
   expect_equal(res, "resolve")
   expect_equal(val, 42)
 })
 
 test_that("def__make_parent_resolve", {
+  testthat::local_edition(3)
   ## NULL
   r1 <- def__make_parent_reject(NULL)
   res <- NULL
   val <- NULL
-  expect_error(
-    r1("foobar", function(x) { res <<- "resolve"; val <<- x }),
-    "foobar"
+  expect_snapshot(
+    error = TRUE,
+    r1("foobar", function(x) {
+      res <<- "resolve"
+      val <<- x
+    })
   )
   expect_null(res)
   expect_null(val)
 
   ## function without args
-  r2 <-  def__make_parent_reject(function() 42 * 42)
+  r2 <- def__make_parent_reject(function() 42 * 42)
   res <- NULL
   val <- NULL
-  r2(42, function(x) { res <<- "resolve"; val <<- x })
+  r2(42, function(x) {
+    res <<- "resolve"
+    val <<- x
+  })
   expect_equal(res, "resolve")
   expect_equal(val, 42 * 42)
 
   ## function with value arg
-  r2 <-  def__make_parent_reject(function(val) val)
+  r2 <- def__make_parent_reject(function(val) val)
   res <- NULL
   val <- NULL
-  r2(42, function(x) { res <<- "resolve"; val <<- x })
+  r2(42, function(x) {
+    res <<- "resolve"
+    val <<- x
+  })
   expect_equal(res, "resolve")
   expect_equal(val, 42)
 })
