@@ -1,13 +1,16 @@
-
 test_that("outside of async context errors", {
   do <- function() {
     x <- event_emitter$new(async = TRUE)
-    x$listen_on("foo", function() {  })
+    x$listen_on("foo", function() {
+    })
     x$emit("foo")
   }
 
-  expect_error(do(), "async context",
-               class = "async_synchronization_barrier_error")
+  expect_error(
+    do(),
+    "async context",
+    class = "async_synchronization_barrier_error"
+  )
 })
 
 test_that("can create event emitter", {
@@ -20,7 +23,8 @@ test_that("can create event emitter", {
 test_that("can add a listener", {
   do <- function() {
     x <- event_emitter$new(async = TRUE)
-    x$listen_on("foo", function() {  })
+    x$listen_on("foo", function() {
+    })
   }
   expect_silent(run_event_loop(do()))
 })
@@ -28,7 +32,8 @@ test_that("can add a listener", {
 test_that("can add a one-shot listener", {
   do <- function() {
     x <- event_emitter$new()
-    x$listen_once("foo", function() {  })
+    x$listen_once("foo", function() {
+    })
   }
   expect_silent(run_event_loop(do()))
 })
@@ -46,7 +51,9 @@ test_that("listener is called on event", {
   deadline <- Sys.time() + as.difftime(2, units = "secs")
   do <- function() {
     x <- event_emitter$new(async = TRUE)
-    x$listen_on("foo", function() { called <<- TRUE })
+    x$listen_on("foo", function() {
+      called <<- TRUE
+    })
     x$emit("foo")
   }
   expect_silent(run_event_loop(do()))
@@ -59,7 +66,9 @@ test_that("listener called multiple times", {
   deadline <- Sys.time() + as.difftime(2, units = "secs")
   do <- function() {
     x <- event_emitter$new(async = TRUE)
-    x$listen_on("foo", function() { called <<- called + 1L })
+    x$listen_on("foo", function() {
+      called <<- called + 1L
+    })
     x$emit("foo")
     x$emit("foo")
     x$emit("foo")
@@ -144,8 +153,12 @@ test_that("one shot listener is only called once", {
 
   do <- function() {
     x <- event_emitter$new(async = TRUE)
-    x$listen_on("foo", function() { called <<- called + 1L })
-    x$listen_once("foo", function() { called1 <<- called1 + 1L })
+    x$listen_on("foo", function() {
+      called <<- called + 1L
+    })
+    x$listen_once("foo", function() {
+      called1 <<- called1 + 1L
+    })
     x$emit("foo")
     x$emit("foo")
     x$emit("foo")
@@ -161,8 +174,12 @@ test_that("can remove listener", {
 
   deadline <- Sys.time() + as.difftime(2, units = "secs")
 
-  cb1 <- function() { called <<- called + 1L }
-  cb2 <- function(x = 1) { called2 <<- called2 + 1L }
+  cb1 <- function() {
+    called <<- called + 1L
+  }
+  cb2 <- function(x = 1) {
+    called2 <<- called2 + 1L
+  }
   do <- function() {
     x <- event_emitter$new(async = TRUE)
     x$listen_on("foo", cb1)
@@ -186,17 +203,19 @@ test_that("only removes one listener instance", {
 
   deadline <- Sys.time() + as.difftime(2, units = "secs")
 
-  cb <- function() { called <<- called + 1L }
+  cb <- function() {
+    called <<- called + 1L
+  }
   do <- function() {
     x <- event_emitter$new(async = TRUE)
     x$listen_on("foo", cb)
     x$listen_on("foo", cb)
-    x$emit("foo")                       # + 2
+    x$emit("foo") # + 2
     x$listen_off("foo", cb)
-    x$emit("foo")                       # + 1
-    x$emit("foo")                       # + 1
+    x$emit("foo") # + 1
+    x$emit("foo") # + 1
     x$listen_off("foo", cb)
-    x$emit("foo")                       # + 0
+    x$emit("foo") # + 0
   }
 
   expect_silent(run_event_loop(do()))
@@ -211,8 +230,12 @@ test_that("multiple events", {
 
   do <- function() {
     x <- event_emitter$new(async = TRUE)
-    x$listen_on("foo", function() { foo <<- TRUE })
-    x$listen_on("bar", function() { bar <<- TRUE })
+    x$listen_on("foo", function() {
+      foo <<- TRUE
+    })
+    x$listen_on("bar", function() {
+      bar <<- TRUE
+    })
     x$emit("foo")
     x$emit("bar")
   }
@@ -227,8 +250,12 @@ test_that("list event names", {
   do <- function() {
     x <- event_emitter$new(async = TRUE)
     n1 <<- x$get_event_names()
-    cb1 <- function() { foo <<- TRUE }
-    cb2 <- function() { bar <<- TRUE }
+    cb1 <- function() {
+      foo <<- TRUE
+    }
+    cb2 <- function() {
+      bar <<- TRUE
+    }
     x$listen_on("foo", cb1)
     n2 <<- x$get_event_names()
     x$listen_on("bar", cb2)
@@ -250,7 +277,9 @@ test_that("get listener count for event", {
   n1 <- n2 <- n3 <- n4 <- n5 <- 0L
   do <- function() {
     x <- event_emitter$new(async = TRUE)
-    cb <- function() { foo <<- TRUE }
+    cb <- function() {
+      foo <<- TRUE
+    }
     n1 <<- x$get_listener_count("foo")
     x$listen_on("foo", cb)
     n2 <<- x$get_listener_count("foo")
@@ -303,13 +332,14 @@ test_that("error callback is called on error", {
 })
 
 test_that("fail stage if no error callback", {
+  testthat::local_edition(3)
   do <- function() {
     x <- event_emitter$new(async = TRUE)
     x$listen_on("foo", function() stop("foobar"))
     x$emit("foo")
   }
 
-  expect_error(run_event_loop(do()), "foobar")
+  expect_snapshot(error = TRUE, run_event_loop(do()))
 })
 
 test_that("all error callbacks are called", {
@@ -334,15 +364,19 @@ test_that("all error callbacks are called", {
 })
 
 test_that("error within error callback", {
+  testthat::local_edition(3)
   err <- NULL
   do <- function() {
     x <- event_emitter$new(async = TRUE)
     x$listen_on("foo", function() stop("foobar"))
-    x$listen_on("error", function(e) { err <<- e; stop("baz")  })
+    x$listen_on("error", function(e) {
+      err <<- e
+      stop("baz")
+    })
     x$emit("foo")
   }
 
-  expect_error(run_event_loop(do()), "baz")
+  expect_snapshot(error = TRUE, run_event_loop(do()))
   expect_false(is.null(err))
   expect_s3_class(err, "error")
   expect_equal(conditionMessage(err), "foobar")
