@@ -1,38 +1,39 @@
-
 test_that("error if async function is called from sync context", {
-
-  mockery::stub(get_default_event_loop, "length", 0)
+  testthat::local_edition(3)
+  fake(get_default_event_loop, "length", 0)
   expect_error(
     get_default_event_loop(),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
 
   expect_error(
     http_get("url"),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
   expect_error(
     async_constant("foobar"),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
   expect_error(
-    delay(1/1000),
-    class = "async_synchronization_barrier_error")
+    delay(1 / 1000),
+    class = "async_synchronization_barrier_error"
+  )
 
   afun <- async(function() 42)
-  expect_error(afun())
+  expect_snapshot(error = TRUE, afun())
 })
 
 test_that("simple tests", {
-
   afun <- async(function() 42)
   expect_equal(
     synchronise(afun()),
     42
   )
 
-  expect_true(synchronise(delay(1/1000)))
+  expect_true(synchronise(delay(1 / 1000)))
 })
 
 test_that("synchronization barriers, async_constant", {
-
   afun <- function() {
     x <- async_constant(42)
     synchronise(afun2(x))
@@ -44,11 +45,11 @@ test_that("synchronization barriers, async_constant", {
 
   expect_error(
     synchronise(afun()),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
 })
 
 test_that("synchronization barriers, async_detect", {
-
   afun <- function() {
     x <- async_constant(1)
     synchronise(afun2(x))
@@ -60,11 +61,11 @@ test_that("synchronization barriers, async_detect", {
 
   expect_error(
     synchronise(afun()),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
 })
 
 test_that("synchronization barriers, async_every", {
-
   afun <- function() {
     x <- async_constant(1)
     synchronise(afun2(x))
@@ -76,12 +77,12 @@ test_that("synchronization barriers, async_every", {
 
   expect_error(
     synchronise(afun()),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
 })
 
 
 test_that("synchronization barriers, async_filter", {
-
   afun <- function() {
     x <- async_constant(1)
     synchronise(afun2(x))
@@ -93,11 +94,11 @@ test_that("synchronization barriers, async_filter", {
 
   expect_error(
     synchronise(afun()),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
 })
 
 test_that("synchronization barriers, async_map", {
-
   afun <- function() {
     x <- async_constant(1)
     synchronise(afun2(x))
@@ -109,11 +110,11 @@ test_that("synchronization barriers, async_map", {
 
   expect_error(
     synchronise(afun()),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
 })
 
 test_that("synchronization barriers, then()", {
-
   afun <- function() {
     x <- async_constant(1)
     synchronise(afun2(x))
@@ -125,11 +126,11 @@ test_that("synchronization barriers, then()", {
 
   expect_error(
     synchronise(afun()),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
 })
 
 test_that("synchronization barriers, when_all", {
-
   afun <- async(function() {
     x <- async_constant(1)
     synchronise(afun2(x))
@@ -142,11 +143,11 @@ test_that("synchronization barriers, when_all", {
 
   expect_error(
     synchronise(afun()),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
 })
 
 test_that("synchronization barriers, when_some", {
-
   afun <- async(function() {
     x <- async_constant(1)
     get_private(x)$null()
@@ -159,7 +160,8 @@ test_that("synchronization barriers, when_some", {
 
   expect_error(
     synchronise(afun()),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
 
   afun2 <- function(x) {
     when_some(1, async_constant(2), x)
@@ -167,11 +169,11 @@ test_that("synchronization barriers, when_some", {
 
   expect_error(
     synchronise(afun()),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
 })
 
 test_that("synchronization barriers, leaked deferred", {
-
   leak <- NULL
   do <- function() {
     leak <<- async_constant(1)
@@ -183,34 +185,37 @@ test_that("synchronization barriers, leaked deferred", {
   expect_false(is.null(leak))
   expect_error(
     synchronise(leak),
-    class = "async_synchronization_barrier_error")
+    class = "async_synchronization_barrier_error"
+  )
 })
 
 test_that("printing async_rejected", {
-  do  <- function() {
-    delay(1/1000)$then(function() stop("oops"))
+  do <- function() {
+    delay(1 / 1000)$then(function() stop("oops"))
   }
 
   res <- tryCatch(synchronise(do()), error = function(e) e)
   expect_match(
     format(res),
-    paste0("<async error: oops\n in *parent* callback of ",
-           "`delay(1/1000)$then` at "),
+    paste0(
+      "<async error: oops\n in *parent* callback of ",
+      "`delay(1/1000)$then` at "
+    ),
     fixed = TRUE
   )
 })
 
 test_that("summary.async_rejected", {
   id <- NULL
-  do  <- function() {
-    p <- delay(1/1000)$then(function() stop("oops"))
+  do <- function() {
+    p <- delay(1 / 1000)$then(function() stop("oops"))
     id <<- get_private(p)$id
     p
   }
 
   res <- tryCatch(synchronise(do()), error = function(e) e)
   sm <- summary(res)
-  fmt <-  format(sm)
+  fmt <- format(sm)
   expect_match(fmt, format(res), fixed = TRUE)
   expect_match(fmt, paste0(id, " parent .*stop[(]\"oops\"[)]"))
 })
