@@ -1,15 +1,13 @@
-
 test_that("when_all", {
   done <- FALSE
   do <- async(function() {
-    d1 <- delay(1/1000)$then(function(value) "foo")
-    d2 <- delay(1/1000)$then(function(value) "bar")
+    d1 <- delay(1 / 1000)$then(function(value) "foo")
+    d2 <- delay(1 / 1000)$then(function(value) "bar")
 
-    when_all(d1, d2)$
-      then(function(value) {
-        done <<- TRUE
-        value
-      })
+    when_all(d1, d2)$then(function(value) {
+      done <<- TRUE
+      value
+    })
   })
   expect_equal(synchronise(do()), list("foo", "bar"))
   expect_true(done)
@@ -18,14 +16,13 @@ test_that("when_all", {
 test_that("when_all, non-deferred", {
   done <- FALSE
   do <- async(function() {
-    d1 <- delay(1/1000)$then(function(value) "foo")
+    d1 <- delay(1 / 1000)$then(function(value) "foo")
     d2 <- "bar"
 
-    when_all(d1, d2)$
-      then(function(value) {
-        done <<- TRUE
-        expect_equal(value, list("foo", "bar"))
-      })
+    when_all(d1, d2)$then(function(value) {
+      done <<- TRUE
+      expect_equal(value, list("foo", "bar"))
+    })
   })
   synchronise(do())
   expect_true(done)
@@ -37,11 +34,10 @@ test_that("when_all, non-deferred only", {
     d1 <- "foo"
     d2 <- "bar"
 
-    when_all(d1, d2)$
-      then(function(value) {
-        done <<- TRUE
-        expect_equal(value, list("foo", "bar"))
-      })
+    when_all(d1, d2)$then(function(value) {
+      done <<- TRUE
+      expect_equal(value, list("foo", "bar"))
+    })
   }
   synchronise(do())
   expect_true(done)
@@ -50,11 +46,10 @@ test_that("when_all, non-deferred only", {
 test_that("when_all, empty list", {
   done <- FALSE
   do <- async(function() {
-    when_all()$
-      then(function(value) {
-        done <<- TRUE
-        expect_equal(value, list())
-      })
+    when_all()$then(function(value) {
+      done <<- TRUE
+      expect_equal(value, list())
+    })
   })
   synchronise(do())
   expect_true(done)
@@ -63,14 +58,13 @@ test_that("when_all, empty list", {
 test_that("when_all, error", {
   done <- FALSE
   do <- async(function() {
-    d1 <- delay(1/1000)$then(function(value) stop("foo"))
-    d2 <- delay(1/1000)$then(function(value) "bar")
+    d1 <- delay(1 / 1000)$then(function(value) stop("foo"))
+    d2 <- delay(1 / 1000)$then(function(value) "bar")
 
-    when_all(d1, d2)$
-      catch(error = function(reason) {
-        done <<-  TRUE
-        expect_match(reason$message, "foo")
-      })
+    when_all(d1, d2)$catch(error = function(reason) {
+      done <<- TRUE
+      expect_match(reason$message, "foo")
+    })
   })
   synchronise(do())
   expect_true(done)
@@ -81,13 +75,12 @@ test_that("when_all, multiple errors", {
   err <- NULL
   do <- async(function() {
     d1 <- delay(2)$then(function(value) stop("foo"))
-    d2 <- delay(1/10000)$then(function(value) stop("bar"))
+    d2 <- delay(1 / 10000)$then(function(value) stop("bar"))
 
-    dx <- when_all(d1, d2)$
-      catch(error = function(reason) {
-        done <<- TRUE
-        err <<- reason
-      })
+    dx <- when_all(d1, d2)$catch(error = function(reason) {
+      done <<- TRUE
+      err <<- reason
+    })
   })
   synchronise(do())
   expect_true(done)
