@@ -1,5 +1,8 @@
-
-if (file.exists("async") && Sys.getenv("NOT_CRAN") == "true") {
+if (
+  file.exists("async") &&
+    Sys.getenv("NOT_CRAN") == "true" &&
+    Sys.getenv("R_COVR") == ""
+) {
   library(testthat)
   library(pkgcache)
   print(sessioninfo::package_info("pkgcache", dependencies = TRUE))
