@@ -1,4 +1,3 @@
-
 test_that("find_in_data_frame", {
   df <- data.frame(
     stringsAsFactors = FALSE,
@@ -9,7 +8,9 @@ test_that("find_in_data_frame", {
   expect_equal(find_in_data_frame(df, foo = "foo"), 1:2)
   expect_equal(find_in_data_frame(df, foo = "foo", bar = "bar"), 1L)
   expect_equal(
-    find_in_data_frame(df, bar = "bar", .list = list(foo = "foo")), 1L)
+    find_in_data_frame(df, bar = "bar", .list = list(foo = "foo")),
+    1L
+  )
   expect_equal(find_in_data_frame(df, bar = "bar", foo = NULL), c(1L, 3L))
 })
 
@@ -20,8 +21,10 @@ test_that("delete_from_data_frame", {
     bar = c("bar", "bar2", "bar")
   )
 
-  expect_equal(delete_from_data_frame(df, foo = "foo"), df[3,])
-  expect_equal(delete_from_data_frame(df, .list = list(bar = "bar2")),
-               df[c(1,3),])
+  expect_equal(delete_from_data_frame(df, foo = "foo"), df[3, ])
+  expect_equal(
+    delete_from_data_frame(df, .list = list(bar = "bar2")),
+    df[c(1, 3), ]
+  )
   expect_equal(delete_from_data_frame(df, foo = "nope"), df)
 })
