@@ -1,4 +1,3 @@
-
 test_that("pkgcache_read_raw", {
   # cannot open file
   expect_match(
@@ -12,9 +11,11 @@ test_that("parse_description", {
   expect_equal(d[["RoxygenNote"]], "7.1.1.9001")
 
   # cannot open file
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     parse_description(tempfile()),
-    "Cannot open file"
+    transform = fix_temp_path,
+    variant = get_os_variant()
   )
 
   # empty file
@@ -28,26 +29,27 @@ test_that("parse_description", {
 
   # invalid files
   d <- ":notgood\n"
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     .Call(pkgcache_parse_description_raw, charToRaw(d)),
-    "must start with an alphanumeric"
+    transform = fix_c_line_number
   )
   d <- "foobar\n"
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     .Call(pkgcache_parse_description_raw, charToRaw(d)),
-    "Line 1 invalid in DESCRIPTION: must be of form `key: value`",
-    fixed = TRUE
+    transform = fix_c_line_number
   )
   d <- "foobar"
-  expect_error(
-    .Call(pkgcache_parse_description_raw, charToRaw(d)),
-    "DESCRIPTION file ended while parsing a key"
+  expect_snapshot(
+    error = TRUE,
+    .Call(pkgcache_parse_description_raw, charToRaw(d))
   )
   d <- "foo: bar\n:nokey\n"
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     .Call(pkgcache_parse_description_raw, charToRaw(d)),
-    "Line 2 invalid in DESCRIPTION: must be of form `key: value`",
-    fixed = TRUE
+    transform = fix_c_line_number
   )
 
   # \r\n line endings
@@ -59,7 +61,9 @@ test_that("parse_description encoding", {
   d <- parse_description(test_path("fixtures/description/pkgcache/DESCRIPTION"))
   expect_equal(Encoding(d[["Authors@R"]]), "UTF-8")
 
-  d2 <- parse_description(test_path("fixtures/description/pkgcachel1/DESCRIPTION"))
+  d2 <- parse_description(test_path(
+    "fixtures/description/pkgcachel1/DESCRIPTION"
+  ))
   expect_equal(Encoding(d2[["Authors@R"]]), "UTF-8")
 })
 
@@ -84,11 +88,11 @@ test_that("parse_packages, RDS", {
 })
 
 test_that("parse_packages, compressed", {
-  p0      <- parse_packages(test_path("fixtures/packages/PACKAGES"))
-  p_gz    <- parse_packages(test_path("fixtures/packages/PACKAGES.gz"))
-  p_bz2   <- parse_packages(test_path("fixtures/packages/PACKAGES.bz2"))
+  p0 <- parse_packages(test_path("fixtures/packages/PACKAGES"))
+  p_gz <- parse_packages(test_path("fixtures/packages/PACKAGES.gz"))
+  p_bz2 <- parse_packages(test_path("fixtures/packages/PACKAGES.bz2"))
   p_bzip2 <- parse_packages(test_path("fixtures/packages/PACKAGES.bzip2"))
-  p_xz    <- parse_packages(test_path("fixtures/packages/PACKAGES.xz"))
+  p_xz <- parse_packages(test_path("fixtures/packages/PACKAGES.xz"))
   expect_equal(p0, p_gz)
   expect_equal(p0, p_bz2)
   expect_equal(p0, p_bzip2)
@@ -96,12 +100,12 @@ test_that("parse_packages, compressed", {
 })
 
 test_that("parse_packages, <CR><LF>", {
-  p0      <- parse_packages(test_path("fixtures/packages/PACKAGES"))
-  p       <- parse_packages(test_path("fixtures/packages/PACKAGES2"))
-  p_gz    <- parse_packages(test_path("fixtures/packages/PACKAGES2.gz"))
-  p_bz2   <- parse_packages(test_path("fixtures/packages/PACKAGES2.bz2"))
+  p0 <- parse_packages(test_path("fixtures/packages/PACKAGES"))
+  p <- parse_packages(test_path("fixtures/packages/PACKAGES2"))
+  p_gz <- parse_packages(test_path("fixtures/packages/PACKAGES2.gz"))
+  p_bz2 <- parse_packages(test_path("fixtures/packages/PACKAGES2.bz2"))
   p_bzip2 <- parse_packages(test_path("fixtures/packages/PACKAGES2.bzip2"))
-  p_xz    <- parse_packages(test_path("fixtures/packages/PACKAGES2.xz"))
+  p_xz <- parse_packages(test_path("fixtures/packages/PACKAGES2.xz"))
   expect_equal(p0, p)
   expect_equal(p0, p_gz)
   expect_equal(p0, p_bz2)
@@ -110,29 +114,31 @@ test_that("parse_packages, <CR><LF>", {
 })
 
 test_that("parse_packages, errors", {
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     parse_packages(tempfile(), type = "uncompressed"),
-    "Cannot open file"
+    transform = fix_temp_path,
+    variant = get_os_variant()
   )
 
   p <- "Package: foo\n\n \n"
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     .Call(pkgcache_parse_packages_raw, charToRaw(p)),
-    "Invalid PACKAGES file in line 3: expected key"
+    transform = fix_c_line_number
   )
 
   p <- "Package: foo\nVersion is not good\nAnother: x\n"
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     .Call(pkgcache_parse_packages_raw, charToRaw(p)),
-    "Invalid line 2 in PACKAGES file: must contain `:`",
-    fixed = TRUE
+    transform = fix_c_line_number
   )
 
   p <- "Package: foo\nimcoplete_key"
-  expect_error(
-    .Call(pkgcache_parse_packages_raw, charToRaw(p)),
-    "PACKAGES file ended while parsing a key",
-    fixed = TRUE
+  expect_snapshot(
+    error = TRUE,
+    .Call(pkgcache_parse_packages_raw, charToRaw(p))
   )
 })
 
@@ -147,6 +153,36 @@ test_that("somewhat weird packages files", {
   expect_equal(pkgs, pkgs2)
 })
 
+test_that("parse_packages empty file", {
+  # cf. https://github.com/r-lib/pkgcache/issues/107
+  tmp <- tempfile()
+  on.exit(unlink(tmp), add = TRUE)
+  file.create(tmp)
+  expect_silent(parse_packages(tmp))
+  expect_snapshot(parse_packages(tmp))
+})
+
+# https://github.com/r-lib/pkgcache/issues/122
+test_that("parse_packages edge case (#122)", {
+  res <- list(Package = "foo")
+  do <- function(cnt) {
+    .Call(pkgcache_parse_packages_raw, charToRaw(cnt))
+  }
+  expect_equal(do("Package: foo"), res)
+  expect_equal(do("Package: foo\n"), res)
+  expect_equal(do("Package: foo\n\n"), res)
+  expect_equal(do("Package: foo\n\n\n"), res)
+  expect_equal(do("Package: foo\n\n\n\n"), res)
+  expect_equal(do("Package: foo\n\n\n\n\n"), res)
+  expect_equal(do("Package: foo\n\n\n\n\n\n"), res)
+
+  res2 <- list(Package = "foo\r")
+  expect_equal(do("Package: foo\r\n"), res2)
+  expect_equal(do("Package: foo\r\n\r\n"), res2)
+  expect_equal(do("Package: foo\r\n\r\n\r\n"), res2)
+  expect_equal(do("Package: foo\r\n\r\n\r\n\r\n"), res2)
+})
+
 test_that("parse_installed", {
   testthat::local_edition(3)
   testthat::local_reproducible_output(width = 60)
@@ -154,7 +190,10 @@ test_that("parse_installed", {
   expect_snapshot(pkgs$Package)
   expect_true("LibPath" %in% names(pkgs))
 
-  pkgs2 <- parse_installed(test_path("fixtures/lib"), packages = c("cli", "foo"))
+  pkgs2 <- parse_installed(
+    test_path("fixtures/lib"),
+    packages = c("cli", "foo")
+  )
   expect_snapshot(pkgs2$Package)
 })
 
@@ -207,7 +246,6 @@ test_that("parse_installed, more errors", {
   out <- .Call(pkgcache_parse_descriptions, tmp, FALSE)
   expect_true(out[[3]])
   expect_match(out[[2]], "Line 2 is invalid")
-
 })
 
 test_that("parse_installed priority", {
@@ -217,7 +255,9 @@ test_that("parse_installed priority", {
   expect_snapshot(parse_installed(lib5, priority = "base")$Package)
   expect_snapshot(parse_installed(lib5, priority = "recommended")$Package)
   expect_snapshot(parse_installed(lib5, priority = NA)$Package)
-  expect_snapshot(parse_installed(lib5, priority = c("base", "recommended"))$Package)
+  expect_snapshot(
+    parse_installed(lib5, priority = c("base", "recommended"))$Package
+  )
   expect_snapshot(parse_installed(lib5, priority = c("base", NA))$Package)
 })
 
@@ -228,7 +268,10 @@ test_that("parse_installed lowercase", {
 })
 
 as_bytes <- function(l) {
-  lapply(l, function(x) { Encoding(x) <- "bytes"; x })
+  lapply(l, function(x) {
+    Encoding(x) <- "bytes"
+    x
+  })
 }
 
 test_that("fix_encodings", {
@@ -237,7 +280,11 @@ test_that("fix_encodings", {
   lst <- as_bytes(list(
     Package = c("foo", "bar", "foobar"),
     Encoding = c(NA_character_, "UTF-8", "latin1"),
-    Maintainer = c("Gabor", "G\u00e1bor", iconv("G\u00e1bor", "UTF-8", "latin1")),
+    Maintainer = c(
+      "Gabor",
+      "G\u00e1bor",
+      iconv("G\u00e1bor", "UTF-8", "latin1")
+    ),
     Bad = c("G\u00e1bor", iconv("G\u00e1bor", "UTF-8", "latin1"), "Gabor")
   ))
   lst2 <- fix_encodings(lst)
@@ -255,7 +302,11 @@ test_that("fix encodings on data frames", {
   lst <- as_bytes(list(
     Package = c("foo", "bar", "foobar"),
     Encoding = c(NA_character_, "UTF-8", "latin1"),
-    Maintainer = c("Gabor", "G\u00e1bor", iconv("G\u00e1bor", "UTF-8", "latin1")),
+    Maintainer = c(
+      "Gabor",
+      "G\u00e1bor",
+      iconv("G\u00e1bor", "UTF-8", "latin1")
+    ),
     Bad = c("G\u00e1bor", iconv("G\u00e1bor", "UTF-8", "latin1"), "Gabor")
   ))
   tbl <- as_data_frame(lst)
