@@ -1,10 +1,13 @@
-
 test_that("invalid PACKAGES file errors", {
   pri <- test_temp_dir()
   rep <- test_temp_dir()
 
   cmc <- cranlike_metadata_cache$new(
-    pri, rep, platforms = "source", bioc = FALSE)
+    pri,
+    rep,
+    platforms = "source",
+    bioc = FALSE
+  )
 
   pri_files <- get_private(cmc)$get_cache_files("primary")
   rep_files <- get_private(cmc)$get_cache_files("replica")
