@@ -1,3 +1,6 @@
+if (Sys.getenv("R_COVR") == "true") {
+  return()
+}
 
 test_that("bioconductor$get_repos", {
   on.exit(bioconductor$.internal$clear_cache())
@@ -13,7 +16,15 @@ test_that("bioconductor$get_repos", {
 test_that("bioconductor$.internal$get_matching_bioc_version", {
   on.exit(bioconductor$.internal$clear_cache())
   setup_fake_apps()
-  rvers <- c("2.15", "2.16", "3.1.0", "3.1.1", "3.2.0", "3.3.1", "3.4.0",
-             "3.5.1")
+  rvers <- c(
+    "2.15",
+    "2.16",
+    "3.1.0",
+    "3.1.1",
+    "3.2.0",
+    "3.3.1",
+    "3.4.0",
+    "3.5.1"
+  )
   expect_silent(lapply(rvers, bioconductor$get_matching_bioc_version))
 })
