@@ -1,3 +1,6 @@
+if (Sys.getenv("R_COVR") == "true") {
+  return()
+}
 
 test_that("repo_get", {
   withr::local_options(repos = character())
@@ -71,7 +74,7 @@ test_that("repo_resolve with PPM", {
   )
   withr::local_options(repos = NULL)
 
-  mockery::stub(
+  fake(
     repo_sugar_ppm,
     "current_r_platform_data",
     data.frame(
@@ -85,13 +88,13 @@ test_that("repo_resolve with PPM", {
     )
   )
 
-  mockery::stub(repo_sugar_ppm, "getRversion", "4.2.2")
+  fake(repo_sugar_ppm, "getRversion", "4.2.2")
   expect_equal(
     repo_sugar_ppm("PPM@2021-01-26", nm = NULL),
     c(CRAN = "https://packagemanager.posit.co/cran/__linux__/jammy/2021-01-26")
   )
 
-  mockery::stub(repo_sugar_ppm, "getRversion", "1.0.0")
+  fake(repo_sugar_ppm, "getRversion", "1.0.0")
   expect_equal(
     repo_sugar_ppm("PPM@2021-01-26", nm = NULL),
     c(CRAN = "https://packagemanager.posit.co/cran/2021-01-26")
@@ -110,7 +113,7 @@ test_that("repo_add", {
   expect_equal(repo_get(), before)
 
   repo_add(URL = "https://my.url", .list = c(PATH = "/foo/bar"))
-  expect_snapshot(repo_get()[1:3,])
+  expect_snapshot(repo_get()[1:3, ])
 })
 
 test_that("with_repo", {
@@ -121,7 +124,7 @@ test_that("with_repo", {
     cli.unicode = FALSE
   )
   expect_snapshot(
-    with_repo(c(URL = "https://my.url"), repo_get()[1,])
+    with_repo(c(URL = "https://my.url"), repo_get()[1, ])
   )
 })
 
@@ -149,10 +152,7 @@ test_that("repo_sugar_path", {
 
 test_that("repo_sugar_mran", {
   withr::local_envvar(PKGCACHE_MRAN_URL = NA_character_)
-  expect_error(
-    repo_sugar_mran("2017-01-31", NULL),
-    "PPM snapshots go back to 2017-10-10 only"
-  )
+  expect_snapshot(error = TRUE, repo_sugar_mran("2017-01-31", NULL))
 
   expect_equal(
     repo_sugar_mran("2020-01-21", NULL),
@@ -185,14 +185,14 @@ test_that("repo_sugar_ppm", {
   )
 
   called <- FALSE
-  mockery::stub(repo_sugar_ppm, "synchronise", function(...) {
+  fake(repo_sugar_ppm, "synchronise", function(...) {
     called <<- TRUE
     NULL
   })
 
-  expect_error(
-    repo_sugar_ppm(as.Date("2017-10-01"), NULL),
-    "PPM snapshots go back to 2017-10-10"
+  expect_snapshot(
+    error = TRUE,
+    repo_sugar_ppm(as.Date("2017-10-01"), NULL)
   )
   expect_true(called)
 })
@@ -208,7 +208,7 @@ test_that("parse_spec", {
     as.Date("2019-11-19")
   )
 
-  mockery::stub(parse_spec, "parse_spec_pkg", TRUE)
+  fake(parse_spec, "parse_spec_pkg", TRUE)
   expect_equal(
     parse_spec("dplyr-1.0.0"),
     TRUE
@@ -217,14 +217,11 @@ test_that("parse_spec", {
 
 test_that("parse_spec_r", {
   called <- FALSE
-  mockery::stub(parse_spec_r, "get_r_versions", function(...) {
+  fake(parse_spec_r, "get_r_versions", function(...) {
     called <<- TRUE
     pkgenv$r_versions
   })
-  expect_error(
-    parse_spec_r("100.0.0"),
-    "Unknown R version"
-  )
+  expect_snapshot(error = TRUE, parse_spec_r("100.0.0"))
   expect_true(called)
 })
 
@@ -236,7 +233,7 @@ test_that("get_r_versions", {
   expect_snapshot(ret)
 
   withr::local_envvar(PKGCACHE_R_VERSIONS_URL = repo$url("/rversionsx"))
-  expect_error(get_r_versions(), "Failed to download R versions from")
+  expect_snapshot(error = TRUE, get_r_versions(), transform = fix_port)
 })
 
 test_that("parse_spec_date", {
@@ -247,28 +244,23 @@ test_that("parse_spec_pkg", {
   testthat::local_edition(3)
   withr::local_envvar(PKGCACHE_CRANDB_URL = repo$url("/crandb/%s"))
 
-  expect_error(parse_spec_pkg("foo-"), "Invalid package version")
-  expect_error(parse_spec_pkg("-1.0.1"), "Invalid package version")
+  expect_snapshot(error = TRUE, {
+    parse_spec_pkg("foo-")
+    parse_spec_pkg("-1.0.1")
+  })
 
   old <- pkgenv$pkg_versions[["dplyr"]]
   on.exit(pkgenv$pkg_versions[["dplyr"]] <- old, add = TRUE)
   pkgenv$pkg_versions[["dplyr"]] <- NULL
 
-  expect_error(
-    parse_spec_pkg("dplyr-0.0.0"),
-    "Unknown 'dplyr' version: '0.0.0'",
-    fixed = TRUE
-  )
+  expect_snapshot(error = TRUE, parse_spec_pkg("dplyr-0.0.0"))
   expect_snapshot(pkgenv$pkg_versions[["dplyr"]])
 
-  expect_error(
-    parse_spec_pkg("foobar-1.0.0"),
-    "Cannot find package versions for"
-  )
-
-  expect_error(
+  expect_snapshot(error = TRUE, parse_spec_pkg("foobar-1.0.0"))
+  expect_snapshot(
+    error = TRUE,
     parse_spec_pkg("bad-1.0.0"),
-    "Failed to download package versions for"
+    transform = fix_port
   )
 
   expect_equal(parse_spec_pkg("dplyr-1.0.0"), as.Date("2020-05-30"))
