@@ -1,16 +1,18 @@
-
 test_package_root <- function() {
   x <- tryCatch(
     rprojroot::find_package_root_file(),
-    error = function(e) NULL)
+    error = function(e) NULL
+  )
 
   if (!is.null(x)) return(x)
 
   pkg <- testthat::testing_package()
   x <- tryCatch(
     rprojroot::find_package_root_file(
-      path = file.path("..", "..", "00_pkg_src", pkg)),
-    error = function(e) NULL)
+      path = file.path("..", "..", "00_pkg_src", pkg)
+    ),
+    error = function(e) NULL
+  )
 
   if (!is.null(x)) return(x)
 
@@ -26,7 +28,8 @@ test_that("spell check", {
   if (nrow(results)) {
     output <- sprintf(
       "Potential spelling errors: %s\n",
-      paste(results$word, collapse = ", "))
+      paste(results$word, collapse = ", ")
+    )
     stop(output, call. = FALSE)
   } else {
     expect_true(TRUE)
